@@ -19,183 +19,6 @@
 **/
 
 
-/**
- * Get trigger severity full line height css style name.
- *
- * @param int $severity  Trigger severity.
- *
- * @return string|null
- */
-function getSeverityFlhStyle($severity) {
-	switch ($severity) {
-		case TRIGGER_SEVERITY_DISASTER:
-			return ZBX_STYLE_FLH_DISASTER_BG;
-		case TRIGGER_SEVERITY_HIGH:
-			return ZBX_STYLE_FLH_HIGH_BG;
-		case TRIGGER_SEVERITY_AVERAGE:
-			return ZBX_STYLE_FLH_AVERAGE_BG;
-		case TRIGGER_SEVERITY_WARNING:
-			return ZBX_STYLE_FLH_WARNING_BG;
-		case TRIGGER_SEVERITY_INFORMATION:
-			return ZBX_STYLE_FLH_INFO_BG;
-		case TRIGGER_SEVERITY_NOT_CLASSIFIED:
-			return ZBX_STYLE_FLH_NA_BG;
-		default:
-			return null;
-	}
-}
-
-/**
- * Get trigger severity status css style name.
- *
- * @param int $severity  Trigger severity.
- *
- * @return string|null
- */
-function getSeverityStatusStyle($severity) {
-	switch ($severity) {
-		case TRIGGER_SEVERITY_DISASTER:
-			return ZBX_STYLE_STATUS_DISASTER_BG;
-		case TRIGGER_SEVERITY_HIGH:
-			return ZBX_STYLE_STATUS_HIGH_BG;
-		case TRIGGER_SEVERITY_AVERAGE:
-			return ZBX_STYLE_STATUS_AVERAGE_BG;
-		case TRIGGER_SEVERITY_WARNING:
-			return ZBX_STYLE_STATUS_WARNING_BG;
-		case TRIGGER_SEVERITY_INFORMATION:
-			return ZBX_STYLE_STATUS_INFO_BG;
-		case TRIGGER_SEVERITY_NOT_CLASSIFIED:
-			return ZBX_STYLE_STATUS_NA_BG;
-		default:
-			return null;
-	}
-}
-
-function getSeverityStyle($severity, $type = true) {
-	if (!$type) {
-		return ZBX_STYLE_NORMAL_BG;
-	}
-
-	switch ($severity) {
-		case TRIGGER_SEVERITY_DISASTER:
-			return ZBX_STYLE_DISASTER_BG;
-		case TRIGGER_SEVERITY_HIGH:
-			return ZBX_STYLE_HIGH_BG;
-		case TRIGGER_SEVERITY_AVERAGE:
-			return ZBX_STYLE_AVERAGE_BG;
-		case TRIGGER_SEVERITY_WARNING:
-			return ZBX_STYLE_WARNING_BG;
-		case TRIGGER_SEVERITY_INFORMATION:
-			return ZBX_STYLE_INFO_BG;
-		case TRIGGER_SEVERITY_NOT_CLASSIFIED:
-			return ZBX_STYLE_NA_BG;
-		default:
-			return null;
-	}
-}
-
-/**
- * Get trigger severity name by given state and configuration.
- *
- * @param int   $severity  Trigger severity.
- *
- * @return string
- */
-function getSeverityName($severity) {
-	switch ($severity) {
-		case TRIGGER_SEVERITY_NOT_CLASSIFIED:
-			return _(CSettingsHelper::get(CSettingsHelper::SEVERITY_NAME_0));
-		case TRIGGER_SEVERITY_INFORMATION:
-			return _(CSettingsHelper::get(CSettingsHelper::SEVERITY_NAME_1));
-		case TRIGGER_SEVERITY_WARNING:
-			return _(CSettingsHelper::get(CSettingsHelper::SEVERITY_NAME_2));
-		case TRIGGER_SEVERITY_AVERAGE:
-			return _(CSettingsHelper::get(CSettingsHelper::SEVERITY_NAME_3));
-		case TRIGGER_SEVERITY_HIGH:
-			return _(CSettingsHelper::get(CSettingsHelper::SEVERITY_NAME_4));
-		case TRIGGER_SEVERITY_DISASTER:
-			return _(CSettingsHelper::get(CSettingsHelper::SEVERITY_NAME_5));
-		default:
-			return _('Unknown');
-	}
-}
-
-function getSeverityColor($severity, $value = TRIGGER_VALUE_TRUE) {
-	if ($value == TRIGGER_VALUE_FALSE) {
-		return 'AAFFAA';
-	}
-
-	switch ($severity) {
-		case TRIGGER_SEVERITY_DISASTER:
-			$color = CSettingsHelper::get(CSettingsHelper::SEVERITY_COLOR_5);
-			break;
-		case TRIGGER_SEVERITY_HIGH:
-			$color = CSettingsHelper::get(CSettingsHelper::SEVERITY_COLOR_4);
-			break;
-		case TRIGGER_SEVERITY_AVERAGE:
-			$color = CSettingsHelper::get(CSettingsHelper::SEVERITY_COLOR_3);
-			break;
-		case TRIGGER_SEVERITY_WARNING:
-			$color = CSettingsHelper::get(CSettingsHelper::SEVERITY_COLOR_2);
-			break;
-		case TRIGGER_SEVERITY_INFORMATION:
-			$color = CSettingsHelper::get(CSettingsHelper::SEVERITY_COLOR_1);
-			break;
-		case TRIGGER_SEVERITY_NOT_CLASSIFIED:
-			$color = CSettingsHelper::get(CSettingsHelper::SEVERITY_COLOR_0);
-			break;
-		default:
-			$color = CSettingsHelper::get(CSettingsHelper::SEVERITY_COLOR_0);
-	}
-
-	return $color;
-}
-
-/**
- * Generate array with severities options.
- *
- * @param int $min  Minimal severity.
- * @param int $max  Maximum severity.
- *
- * @return array
- */
-function getSeverities($min = TRIGGER_SEVERITY_NOT_CLASSIFIED, $max = TRIGGER_SEVERITY_COUNT - 1) {
-	$severities = [];
-
-	foreach (range($min, $max) as $severity) {
-		$severities[] = [
-			'name' => getSeverityName($severity),
-			'value' => $severity,
-			'style' => getSeverityStyle($severity)
-		];
-	}
-
-	return $severities;
-}
-
-/**
- * Returns HTML representation of trigger severity cell containing severity name and color.
- *
- * @param int         $severity       Trigger, Event or Problem severity.
- * @param string|null $text           Trigger severity name.
- * @param bool        $force_normal   True to return 'normal' class, false to return corresponding severity class.
- * @param bool        $return_as_div  True to return severity cell as DIV element.
- *
- * @return CDiv|CCol
- */
-function getSeverityCell($severity, $text = null, $force_normal = false, $return_as_div = false) {
-	if ($text === null) {
-		$text = CHtml::encode(getSeverityName($severity));
-	}
-
-	if ($force_normal) {
-		return new CCol($text);
-	}
-
-	$return = $return_as_div ? new CDiv($text) : new CCol($text);
-	return $return->addClass(getSeverityStyle($severity));
-}
-
 /**
  * Add color style and blinking to an object like CSpan or CDiv depending on trigger status.
  * Settings and colors are kept in 'config' database table.
@@ -265,7 +88,7 @@ function get_trigger_by_triggerid($triggerid) {
 	if (!empty($db_trigger)) {
 		return $db_trigger;
 	}
-	error(_s('No trigger with triggerid "%1$s".', $triggerid));
+	error(_s('No trigger with trigger ID "%1$s".', $triggerid));
 
 	return false;
 }
@@ -709,11 +532,12 @@ function getTriggersOverviewData(array $groupids, array $host_options = [], arra
 		'show_suppressed' => ZBX_PROBLEM_SUPPRESSED_FALSE
 	];
 
-	$limit = (int) CSettingsHelper::get(CSettingsHelper::MAX_OVERVIEW_TABLE_SIZE);
-
+	$limit = 0;
 	do {
+		$limit += (int) CSettingsHelper::get(CSettingsHelper::MAX_OVERVIEW_TABLE_SIZE);
+
 		$db_hosts = API::Host()->get(['limit' => $limit + 1] + $host_options);
-		$fetch_hosts = (count($db_hosts) > $limit);
+		$fetch_more = (count($db_hosts) > $limit);
 
 		$db_triggers = getTriggersWithActualSeverity([
 			'hostids' => array_keys($db_hosts)
@@ -731,11 +555,7 @@ function getTriggersOverviewData(array $groupids, array $host_options = [], arra
 		}
 
 		$db_hosts = array_intersect_key($db_hosts, $represented_hosts);
-
-		$fetch_hosts &= (count($db_hosts) < $limit);
-		$limit += (int) CSettingsHelper::get(CSettingsHelper::MAX_OVERVIEW_TABLE_SIZE);
-
-	} while ($fetch_hosts);
+	} while ($fetch_more && count($db_hosts) < $limit);
 
 	CArrayHelper::sort($db_hosts, [
 		['field' => 'name', 'order' => ZBX_SORT_UP]
@@ -904,7 +724,7 @@ function getTriggerOverviewCell(array $trigger, array $dependencies): CCol {
 		: [];
 
 	$column = (new CCol([$desc, $ack]))
-		->addClass(getSeverityStyle($trigger['priority'], $trigger['value'] == TRIGGER_VALUE_TRUE))
+		->addClass(CSeverityHelper::getStyle((int) $trigger['priority'], $trigger['value'] == TRIGGER_VALUE_TRUE))
 		->addClass(ZBX_STYLE_CURSOR_POINTER);
 
 	$eventid = 0;
@@ -1142,7 +962,7 @@ function make_trigger_details($trigger, $eventid) {
 		])
 		->addRow([
 			_('Severity'),
-			getSeverityCell($trigger['priority'])
+			CSeverityHelper::makeSeverityCell((int) $trigger['priority'])
 		]);
 
 	$trigger = CMacrosResolverHelper::resolveTriggerExpressions(zbx_toHash($trigger, 'triggerid'), [
@@ -1819,8 +1639,11 @@ function get_item_function_info(string $expr) {
 
 	$hist_functions = [
 		'avg' => $rules['numeric_as_float'],
+		'baselinedev' => $rules['numeric_as_float'],
+		'baselinewma' => $rules['numeric_as_float'],
 		'change' => $rules['numeric'] + $rules['string_as_0or1'],
 		'count' => $rules['numeric_as_uint'] + $rules['string_as_uint'],
+		'changecount' => $rules['numeric_as_uint'] + $rules['string_as_uint'],
 		'countunique' => $rules['numeric_as_uint'] + $rules['string_as_uint'],
 		'find' => $rules['numeric_as_0or1'] + $rules['string_as_0or1'],
 		'first' => $rules['numeric'] + $rules['string'],
@@ -1834,8 +1657,11 @@ function get_item_function_info(string $expr) {
 		'mad' => $rules['numeric_as_float'],
 		'max' => $rules['numeric'],
 		'min' => $rules['numeric'],
+		'monodec' => $rules['numeric_as_uint'],
+		'monoinc' => $rules['numeric_as_uint'],
 		'nodata' => $rules['numeric_as_0or1'] + $rules['string_as_0or1'],
 		'percentile' => $rules['numeric'],
+		'rate' => $rules['numeric'],
 		'skewness' => $rules['numeric_as_float'],
 		'stddevpop' => $rules['numeric_as_float'],
 		'stddevsamp' => $rules['numeric_as_float'],
@@ -1846,6 +1672,7 @@ function get_item_function_info(string $expr) {
 		'trendcount' => $rules['numeric'],
 		'trendmax' => $rules['numeric'],
 		'trendmin' => $rules['numeric'],
+		'trendstl' => $rules['numeric'],
 		'trendsum' => $rules['numeric'],
 		'varpop' => $rules['numeric_as_float'],
 		'varsamp' => $rules['numeric_as_float']
@@ -2580,7 +2407,7 @@ function makeTriggerDependencies(array $dependencies, $freeze_on_click = true) {
 				$table->addRow($description);
 			}
 
-			$result[] = (new CSpan())
+			$result[] = (new CLink())
 				->addClass($class)
 				->addClass(ZBX_STYLE_CURSOR_POINTER)
 				->setHint($table, '', $freeze_on_click);
